@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -19,6 +18,7 @@
 #include "gdcmSequenceOfFragments.h"
 #include "gdcmSequenceOfItems.h"
 #include "gdcmImplicitDataElement.h"
+#include "gdcmTrace.h"
 
 namespace gdcm
 {
@@ -117,7 +117,8 @@ namespace gdcm
             assert( item == itemPMSStart );
             ss.seekg(-4,std::ios::cur);
             sqi->Read<ExplicitDataElement,SwapperDoOp>( ss );
-            (void)ex;//cast to avoid the warning message
+			(void)ex;  //to avoid unreferenced variable warning on release
+			gdcmErrorMacro(ex.what());
             }
           return sqi;
           }
@@ -135,7 +136,7 @@ namespace gdcm
             ss.str( s );
             sqi->Read<ImplicitDataElement,SwapperNoOp>( ss );
             }
-          catch ( Exception &ex )
+          catch ( Exception & )
             {
             // Some people like to skew things up and write invalid SQ in VR:UN field
             // if conversion fails, simply keep the binary VR:UN stuff as-is
@@ -144,8 +145,16 @@ namespace gdcm
             // s -> gdcm::ImplicitDataElement -> Impossible (more)
             std::stringstream ss;
             ss.str(s);
-            sqi->Read<ExplicitDataElement,SwapperDoOp>( ss );
-            (void)ex;//cast to avoid the warning message
+            try
+              {
+              sqi->Read<ExplicitDataElement,SwapperDoOp>( ss );
+              }
+            catch ( Exception & )
+              {
+              gdcmErrorMacro( "Could not read SQ. Giving up" );
+              throw "Could not decode this SQ";
+              return NULL;
+              }
             }
           return sqi;
           }
@@ -173,4 +182,13 @@ namespace gdcm
     return 0;
     }
 
+//#if !defined(GDCM_LEGACY_REMOVE)
+//  ByteValue* DataElement::GetByteValue()
+//    {
+//    // Get the raw pointer from the gdcm::SmartPointer
+//    ByteValue *bv = dynamic_cast<ByteValue*>(ValueField.GetPointer());
+//    return bv; // Will return NULL if not ByteValue
+//    }
+//#endif
+
 } // end namespace gdcm
