@@ -45,7 +45,7 @@ double Image::GetSpacing(unsigned int idx) const
 void Image::SetSpacing(const double *spacing)
 {
   assert( NumberOfDimensions );
-  Spacing = std::vector<double>(spacing, 
+  Spacing = std::vector<double>(spacing,
     spacing+NumberOfDimensions);
 }
 
@@ -87,7 +87,7 @@ void Image::SetOrigin(const float *ori)
 void Image::SetOrigin(const double *ori)
 {
   assert( NumberOfDimensions );
-  Origin = std::vector<double>(ori, 
+  Origin = std::vector<double>(ori,
     ori+NumberOfDimensions);
 }
 
@@ -127,7 +127,7 @@ void Image::SetDirectionCosines(const float *dircos)
 void Image::SetDirectionCosines(const double *dircos)
 {
   assert( NumberOfDimensions );
-  DirectionCosines = std::vector<double>(dircos, 
+  DirectionCosines = std::vector<double>(dircos,
     dircos+6);
 }
 
@@ -139,69 +139,52 @@ void Image::SetDirectionCosines(unsigned int idx, double dircos)
 
 void Image::Print(std::ostream &os) const
 {
-  Object::Print(os);
-  //assert( NumberOfDimensions );
-  os << "NumberOfDimensions: " << NumberOfDimensions << "\n";
+  Pixmap::Print(os);
   if( NumberOfDimensions )
     {
-    assert( Dimensions.size() );
-    os << "Dimensions: (";
-    std::vector<unsigned int>::const_iterator it = Dimensions.begin();
-    os << *it;
-    for(++it; it != Dimensions.end(); ++it)
       {
-      os << "," << *it;
+      os << "Origin: (";
+      if( !Origin.empty() )
+        {
+        std::vector<double>::const_iterator it = Origin.begin();
+        os << *it;
+        for(++it; it != Origin.end(); ++it)
+          {
+          os << "," << *it;
+          }
+        }
+      os << ")\n";
       }
-    os << ")\n";
-{
-  os << "Origin: (";
-  if( !Origin.empty() )
-    {
-    std::vector<double>::const_iterator it = Origin.begin();
-    os << *it;
-    for(++it; it != Origin.end(); ++it)
       {
-      os << "," << *it;
+      os << "Spacing: (";
+      std::vector<double>::const_iterator it = Spacing.begin();
+      os << *it;
+      for(++it; it != Spacing.end(); ++it)
+        {
+        os << "," << *it;
+        }
+      os << ")\n";
       }
-    }
-  os << ")\n";
-}
-{
-    os << "Spacing: (";
-    std::vector<double>::const_iterator it = Spacing.begin();
-    os << *it;
-    for(++it; it != Spacing.end(); ++it)
       {
-      os << "," << *it;
+      os << "DirectionCosines: (";
+      if( !DirectionCosines.empty() )
+        {
+        std::vector<double>::const_iterator it = DirectionCosines.begin();
+        os << *it;
+        for(++it; it != DirectionCosines.end(); ++it)
+          {
+          os << "," << *it;
+          }
+        }
+      os << ")\n";
       }
-    os << ")\n";
-}
-{
-  os << "DirectionCosines: (";
-  if( !DirectionCosines.empty() )
-    {
-    std::vector<double>::const_iterator it = DirectionCosines.begin();
-    os << *it;
-    for(++it; it != DirectionCosines.end(); ++it)
       {
-      os << "," << *it;
+      os << "Rescale Intercept/Slope: (" << Intercept << "," << Slope << ")\n";
       }
-    }
-  os << ")\n";
-}
-{
-  os << "Rescale Intercept/Slope: (" << Intercept << "," << Slope << ")\n";
-}
     //std::vector<double> Spacing;
     //std::vector<double> Origin;
 
-    PF.Print(os);
     }
-  os << "PhotometricInterpretation: " << PI << "\n";
-  os << "PlanarConfiguration: " << PlanarConfiguration << "\n";
-  os << "TransferSyntax: " << TS << "\n";
 }
 
-
 } // end namespace gdcm
-
