@@ -639,7 +639,7 @@ bool GetRescaleInterceptSlopeValueFromDataSet(const DataSet& ds, std::vector<dou
       if( interceptslope[1] == 0 )
         {
         // come' on ! WTF
-        gdcmWarningMacro( "Cannot have slope == 0. Defaulting to 1.0 instead" );
+        gdcmDebugMacro( "Cannot have slope == 0. Defaulting to 1.0 instead" );
         interceptslope[1] = 1;
         }
       }
@@ -707,69 +707,57 @@ std::vector<unsigned int> ImageHelper::GetDimensionsValue(const File& f)
 {
   DataSet const & ds = f.GetDataSet();
 
-  //const DataSet& ds = inF.GetDataSet();
+  MediaStorage ms;
+  ms.SetFromFile(f);
   std::vector<unsigned int> theReturn(3);
-  {
-    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0011) );
-    Attribute<0x0028,0x0011> at = { 0 };
-    at.SetFromDataSet( ds );
-    theReturn[0] = at.GetValue();
-    //if( theReturn[0] == 0 )
-    //  {
-    //  // come' on ! WTF
-    //  gdcmWarningMacro( "Cannot find image extent tag 0x0028, 0x0011.  Defaulting to the almost certainly wrong value of 1." );
-    //  theReturn[0] = 1;
-    //  }
-  }
-
-  // D 0028|0010 [US] [Rows] [512]
-  {
-    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
-    Attribute<0x0028,0x0010> at = { 0 };
-    at.SetFromDataSet( ds );
-    theReturn[1] = at.GetValue();
-    //if( theReturn[1] == 0 )
-    //  {
-    //  // come' on ! WTF
-    //  gdcmWarningMacro( "Cannot find image extent tag 0x0028, 0x0010.  Defaulting to the almost certainly wrong value of 1." );
-    //  theReturn[1] = 1;
-    //  }
-  }
-#if 0
-  // D 0054|0081 [US] [Planes] [512]
-  {
-    //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
-    Tag thePlanes(0x0054,0x0081);
-    if (ds.FindDataElement(thePlanes)){
-      Attribute<0x0054,0x0081> at = { 0 };
-      at.SetFromDataSet( ds );
-      theReturn[2] = at.GetValue();
-    } else {
-      theReturn[2] = 1;
-    }
-    //if( theReturn[1] == 0 )
-    //  {
-    //  // come' on ! WTF
-    //  gdcmWarningMacro( "Cannot find image extent tag 0x0028, 0x0010.  Defaulting to the almost certainly wrong value of 1." );
-    //  theReturn[1] = 1;
-    //  }
-  }
-#else
-  {
-  Attribute<0x0028,0x0008> at = { 0 };
-  at.SetFromDataSet( ds );
-  int numberofframes = at.GetValue();
-  theReturn[2] = 1;
-  if( numberofframes > 1 )
     {
-    theReturn[2] = at.GetValue();
+      {
+      Attribute<0x0028,0x0011> at = { 0 };
+      at.SetFromDataSet( ds );
+      theReturn[0] = at.GetValue();
+      }
+      {
+      Attribute<0x0028,0x0010> at = { 0 };
+      at.SetFromDataSet( ds );
+      theReturn[1] = at.GetValue();
+      }
+      {
+      Attribute<0x0028,0x0008> at = { 0 };
+      at.SetFromDataSet( ds );
+      int numberofframes = at.GetValue();
+      theReturn[2] = 1;
+      if( numberofframes > 1 )
+        {
+        theReturn[2] = at.GetValue();
+        }
+      }
     }
-  }
 
-#endif
   return theReturn;
 }
 
+void ImageHelper::SetDimensionsValue(File& f, const Image & img)
+{
+  const unsigned int *dims = img.GetDimensions();
+  MediaStorage ms;
+  ms.SetFromFile(f);
+  DataSet& ds = f.GetDataSet();
+  assert( MediaStorage::IsImage( ms ) );
+    {
+    Attribute<0x0028,0x0010> rows;
+    rows.SetValue( dims[1] );
+    ds.Replace( rows.GetAsDataElement() );
+    Attribute<0x0028,0x0011> columns;
+    columns.SetValue( dims[0] );
+    ds.Replace( columns.GetAsDataElement() );
+    if( dims[2] > 1 )
+      {
+      Attribute<0x0028,0x0008> numframes;
+      ds.Replace( numframes.GetAsDataElement() );
+      }
+    }
+}
+
 std::vector<double> ImageHelper::GetRescaleInterceptSlopeValue(File const & f)
 {
   std::vector<double> interceptslope;
@@ -1100,6 +1088,9 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
     sp.push_back( 1.0 );
     }
   assert( sp.size() == 2 );
+  // Make sure multiframe:
+  std::vector<unsigned int> dims = ImageHelper::GetDimensionsValue( f );
+
   // Do Z:
   Tag zspacingtag = ImageHelper::GetZSpacingTagFromMediaStorage(ms);
   if( zspacingtag != Tag(0xffff,0xffff) && ds.FindDataElement( zspacingtag ) )
@@ -1131,7 +1122,10 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
             el.SetLength( entry.GetVM().GetLength() * entry.GetVR().GetSizeof() );
             el.Read( ss );
             for(unsigned long i = 0; i < el.GetLength(); ++i)
-              sp.push_back( el.GetValue(i) );
+              {
+              const double value = el.GetValue(i);
+              sp.push_back( value );
+              }
             //assert( sp.size() == entry.GetVM() );
             }
           break;
@@ -1174,7 +1168,15 @@ $ dcmdump D_CLUNIE_NM1_JPLL.dcm" | grep 0028,0009
         {
         Attribute<0x0018,0x1063> at2;
         at2.SetFromDataElement( de2 );
-        sp.push_back( at2.GetValue() );
+        if( dims[2] > 1 )
+          {
+          sp.push_back( at2.GetValue() );
+          }
+        else
+          {
+          assert( at2.GetValue() == 0. );
+          sp.push_back( 1.0 );
+          }
         }
       else
         {
@@ -1189,6 +1191,10 @@ $ dcmdump D_CLUNIE_NM1_JPLL.dcm" | grep 0028,0009
     }
 
   assert( sp.size() == 3 );
+  assert( sp[0] != 0. );
+  assert( sp[1] != 0. );
+  if( ms != MediaStorage::MRImageStorage )
+    assert( sp[2] != 0. );
   return sp;
 }
 
