@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -200,7 +199,9 @@ uint8_t PixelFormat::GetPixelSize() const
     pixelsize = 2; // fake a short value
     }
   else
+    {
     assert( !(BitsAllocated % 8) );
+    }
   pixelsize *= SamplesPerPixel;
 
   return pixelsize;
@@ -285,11 +286,16 @@ bool PixelFormat::Validate()
   if ( BitsAllocated == 24 )
     {
     gdcmDebugMacro( "ACR-NEMA way of storing RGB data. Updating" );
-    assert( BitsStored == 24 && HighBit == 23 && SamplesPerPixel == 1 );
-    BitsAllocated = 8;
-    BitsStored = 8;
-    HighBit = 7;
-    SamplesPerPixel = 3;
+    if( BitsStored == 24 && HighBit == 23 && SamplesPerPixel == 1 )
+      {
+      BitsAllocated = 8;
+      BitsStored = 8;
+      HighBit = 7;
+      SamplesPerPixel = 3;
+      return true;
+      }
+    // all other case, simply give up
+    return false;
     }
   return true;
 }
