@@ -541,7 +541,6 @@ bool DoOverlays(const DataSet& ds, Pixmap& pixeldata)
 bool PixmapReader::ReadImage(MediaStorage const &ms)
 {
   const DataSet &ds = F->GetDataSet();
-  std::stringstream ss;
   std::string conversion;
 
   bool isacrnema = false;
@@ -558,93 +557,24 @@ bool PixmapReader::ReadImage(MediaStorage const &ms)
     (void)str;//warning removal
     }
 
-  // Ok we have the dataset let's feed the Image (PixelData)
-  // 1. First find how many dimensions there is:
-  // D 0028|0008 [IS] [Number of Frames] [8 ]
-  const Tag tnumberofframes = Tag(0x0028, 0x0008);
-  //if( ds.FindDataElement( tnumberofframes ) /*&& ms != MediaStorage::SecondaryCaptureImageStorage*/ )
+  std::vector<unsigned int> vdims = ImageHelper::GetDimensionsValue(*F);
+  unsigned int numberofframes = vdims[2];
+  // What should I do when numberofframes == 0 ?
+  if( numberofframes > 1 )
     {
-    //const DataElement& de = ds.GetDataElement( tnumberofframes );
-    Attribute<0x0028,0x0008> at = { 0 };
-    at.SetFromDataSet( ds );
-    int numberofframes = at.GetValue();
-    // What should I do when numberofframes == 0 ?
-    if( numberofframes > 1 )
-      {
-      PixelData->SetNumberOfDimensions(3);
-      PixelData->SetDimension(2, numberofframes );
-      }
-    else
-      {
-      gdcmDebugMacro( "NumberOfFrames was specified with a value of: "
-        << numberofframes );
-      PixelData->SetNumberOfDimensions(2);
-      }
+    PixelData->SetNumberOfDimensions(3);
+    PixelData->SetDimension(2, numberofframes );
+    }
+  else
+    {
+    gdcmDebugMacro( "NumberOfFrames was specified with a value of: "
+      << numberofframes );
+    PixelData->SetNumberOfDimensions(2);
     }
-  //else
-  //  {
-  //  gdcmDebugMacro( "Attempting a guess for the number of dimensions" ); // FIXME
-  //  PixelData->SetNumberOfDimensions(2);
-  //  }
-
 
   // 2. What are the col & rows:
-  // D 0028|0011 [US] [Columns] [512]
-  //const Tag tcolumns(0x0028, 0x0011);
-  //if( ds.FindDataElement( tcolumns ) )
-    {
-    //PixelData->SetDimension(0,
-    //  ReadUSFromTag( tcolumns, ss, conversion ) );
-    //const DataElement& de = ds.GetDataElement( tcolumns );
-    Attribute<0x0028,0x0011> at = { 0 };
-    at.SetFromDataSet( ds );
-    PixelData->SetDimension(0, at.GetValue() );
-    }
-  //else
-  //  {
-  //  const TransferSyntax &ts = PixelData->GetTransferSyntax();
-  //  gdcmWarningMacro( "This should not happen: No Columns found." );
-  //  if( !ts.IsEncapsulated() || ts == TransferSyntax::RLELossless )
-  //    {
-  //    // Pretty bad we really need this information. Should not
-  //    // happen in theory. Maybe papyrus files ??
-  //    return false;
-  //    }
-  //  }
-
-  // D 0028|0010 [US] [Rows] [512]
-  //PixelData->SetDimension(1,
-  //  ReadUSFromTag( Tag(0x0028, 0x0010), ss, conversion ) );
-    {
-    Attribute<0x0028,0x0010> at = { 0 };
-    //if( ds.FindDataElement( at.GetTag() ) )
-      {
-      //const DataElement& de = ds.GetDataElement( at.GetTag() );
-      at.SetFromDataSet( ds );
-      PixelData->SetDimension(1, at.GetValue() );
-      //assert( at.GetValue() == ReadUSFromTag( Tag(0x0028, 0x0010), ss, conversion ) );
-      }
-    //else
-    //  {
-    //  const TransferSyntax &ts = PixelData->GetTransferSyntax();
-    //  gdcmWarningMacro( "This should not happen: No Rows found." );
-    //  if( !ts.IsEncapsulated() || ts == TransferSyntax::RLELossless )
-    //    {
-    //    // Pretty bad we really need this information. Should not
-    //    // happen in theory. Maybe papyrus files ??
-    //    return false;
-    //    }
-    //  }
-    }
-
-  // Dummy check
-  //const unsigned int *dims = PixelData->GetDimensions();
-  //if( dims[0] == 0 || dims[1] == 0 )
-  //  {
-  //  // PhilipsLosslessRice.dcm
-  //  gdcmWarningMacro( "Image is empty" );
-  //  return false;
-  //  }
+  PixelData->SetDimension(0, vdims[0] );
+  PixelData->SetDimension(1, vdims[1] );
 
   // 3. Pixel Format ?
   PixelFormat pf;
@@ -1009,8 +939,8 @@ bool PixmapReader::ReadImage(MediaStorage const &ms)
       sqf->WriteBuffer( ss );
       //std::string s( bv->GetPointer(), bv->GetLength() );
       //is.str( s );
-      gdcm::PixelFormat pf ( gdcm::PixelFormat::UINT8 ); // usual guess...
-      jpeg.SetPixelFormat( pf );
+      gdcm::PixelFormat jpegpf ( gdcm::PixelFormat::UINT8 ); // usual guess...
+      jpeg.SetPixelFormat( jpegpf );
       gdcm::TransferSyntax ts;
       bool b = jpeg.GetHeaderInfo( ss, ts );
       if( b )
@@ -1041,7 +971,32 @@ bool PixmapReader::ReadImage(MediaStorage const &ms)
       }
     }
 
-  PixelData->ComputeLossyFlag();
+  // Let's be smart when computing the lossyflag (0028,2110) 
+  // LossyImageCompression
+  Attribute<0x0028,0x2110> licat;
+  bool lossyflag = false;
+  bool haslossyflag = false;
+  if( ds.FindDataElement( licat.GetTag() ) )
+    {
+    haslossyflag = true;
+    licat.SetFromDataSet( ds ); // could be empty
+    const CSComp & v = licat.GetValue();
+    lossyflag = atoi( v.c_str() ) == 1;
+    PixelData->SetLossyFlag(lossyflag);
+    }
+
+  // Two cases:
+  // - DataSet did not specify the lossyflag
+  // - DataSet specify it to be 0, but there is still a change it could be wrong:
+  if( !haslossyflag || !lossyflag )
+    {
+    PixelData->ComputeLossyFlag();
+    if( PixelData->IsLossy() && (!lossyflag && haslossyflag ) )
+      {
+      // We always prefer the setting from the stream...
+      gdcmWarningMacro( "DataSet set LossyFlag to 0, while Codec made the stream lossy" );
+      }
+    }
 
   return true;
 }
@@ -1058,21 +1013,21 @@ bool PixmapReader::ReadACRNEMAImage()
   const Tag timagedimensions = Tag(0x0028, 0x0005);
   if( ds.FindDataElement( timagedimensions ) )
     {
-    const DataElement& de = ds.GetDataElement( timagedimensions );
-    Attribute<0x0028,0x0005> at = { 0 };
-    at.SetFromDataElement( de );
-    assert( at.GetNumberOfValues() == 1 );
-    unsigned short imagedimensions = at.GetValue();
+    const DataElement& de0 = ds.GetDataElement( timagedimensions );
+    Attribute<0x0028,0x0005> at0 = { 0 };
+    at0.SetFromDataElement( de0 );
+    assert( at0.GetNumberOfValues() == 1 );
+    unsigned short imagedimensions = at0.GetValue();
     //assert( imagedimensions == ReadSSFromTag( timagedimensions, ss, conversion ) );
     if ( imagedimensions == 3 )
       {
       PixelData->SetNumberOfDimensions(3);
       // D 0028|0012 [US] [Planes] [262]
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0012) );
-      Attribute<0x0028,0x0012> at = { 0 };
-      at.SetFromDataElement( de );
-      assert( at.GetNumberOfValues() == 1 );
-      PixelData->SetDimension(2, at.GetValue() );
+      const DataElement& de1 = ds.GetDataElement( Tag(0x0028, 0x0012) );
+      Attribute<0x0028,0x0012> at1 = { 0 };
+      at1.SetFromDataElement( de1 );
+      assert( at1.GetNumberOfValues() == 1 );
+      PixelData->SetDimension(2, at1.GetValue() );
       //assert( at.GetValue() == ReadUSFromTag( Tag(0x0028, 0x0012), ss, conversion ) );
       }
     else if ( imagedimensions == 2 )
