@@ -140,148 +140,7 @@ void Printer::SetColor(bool c)
 
 void PrintValue(VR::VRType const &vr, VM const &vm, const Value &v);
 
-//-----------------------------------------------------------------------------
-void Printer::PrintElement(std::ostream& os, const DataElement &xde, const DictEntry& entry)
-{
-  assert(0);
-  const Tag &t = xde.GetTag();
-  const VR &vr = xde.GetVR();
-  const VL &vl = xde.GetVL();
-  const Value& value = xde.GetValue();
-  VR lvr = vr;
-
-  // FIXME:
-  if( xde.IsEmpty() // 0xfffe item thingy
-    || entry.GetVR() == VR::INVALID ) // private element with no known VR
-    {
-    os << xde;
-    return;
-    }
-  // first of' do the VR:
-  if( lvr == VR::UN )
-    {
-    if( t.GetElement() == 0x0 || t.GetElement() == 0x1 ) // is 0x1 actually UN ?
-      {
-      lvr = VR::UL;
-      }
-    else
-      {
-      //assert( t.IsPublic() );
-      lvr = entry.GetVR();
-      }
-    // Data Element (7FE0,0010) Pixel Data has the Value Representation
-    // OW and shall be encoded in Little Endian.
-    if( t == Tag(0x7fe0,0x0010) )
-      {
-      assert( lvr == VR::OB_OW );
-      lvr = VR::OW;
-      }
-    //if( lvr == VR::UN ) lvr = VR::LO; // why not ?
-    }
-
-  VM vm = entry.GetVM();
-  if( vm == VM::VM0 )
-    {
-    assert( lvr != VR::UN );
-    //assert( lvr != VR::INVALID );
-    assert( t.IsPrivate() || t.GetElement() == 0x0 );
-    if ( lvr & VR::OB_OW )
-      {
-      vm = VM::VM1;
-      }
-    else
-      {
-      vm = VM::GetVMTypeFromLength( value.GetLength(), lvr.GetSize() );
-      //gdcmWarningMacro( "VM for " << vm );
-      if( t.GetElement() == 0x0 )
-        {
-        //gdcmWarningMacro( "Lgt= " << value.GetLength() << " size= " << vr.GetSize() );
-        //assert( vm == VM::VM1 && lvr == VR::UL );
-        if( vm != VM::VM1 )  gdcmWarningMacro( "Problem with " << t << " VM would be " << vm );
-        }
-      }
-    }
-  // Print Tag and VR:
-  os << t << " " << lvr;
-  if( lvr == VR::INVALID )
-    {
-    os << "(" << entry.GetVR() << ")";
-    }
-  //os << " " << VM::GetVMString( vm ) ;
-  //  if( dictVR != VR::INVALID && !(vr & dictVR) )
-  //    {
-  //    gdcmErrorMacro( "Wrong VR should be " << dictVR );
-  //    // LEADTOOLS_FLOWERS-8-PAL-RLE.dcm has (0040,0253) : CS instead of SH
-  //    //assert(0);
-  //    }
-  //  if( pstyle == Printer::CONDENSED_STYLE )
-  //    {
-  //    (void)vl;
-  //    _os /*<< "\t " << std::dec << vl  */
-  //      << " [" << value << "]";
-  //    }
-
-  if( !entry.GetVR().Compatible( lvr ) )
-    {
-    gdcmErrorMacro( "Wrong VR should be " << entry.GetVR() );
-    }
-  if( VR::IsASCII(lvr) )
-    {
-    // TODO FIXME (value is a null object)
-    if( vl ) os << " [" << value << "] ";
-    }
-  else if ( lvr == VR::SQ || vl.IsUndefined() )
-    {
-    //      os << "DEBUG";
-    //      value.Print( _os );
-    }
-  else if ( VR::IsBinary(lvr) )
-    {
-    //os << "\t ValueField=[";
-    os << " ";
-    if( vl ) PrintValue(lvr, vm, value );
-    //os << "]";
-    os << " ";
-    }
-  else
-    {
-    std::cerr << "Should not happen: " << lvr << std::endl;
-    }
-  //
-  os << "\t\t# " << std::dec << vl;
-  os << ", 1";
-
-  if( vl.IsUndefined() ) { assert ( t == Tag(0x7fe0, 0x0010) || lvr == VR::SQ ) ; }
-  if ( lvr == VR::SQ )
-    {
-    os << std::endl;
-    const SequenceOfItems &sqi = static_cast<const SequenceOfItems&>(value);
-    SequenceOfItems::ItemVector::const_iterator it = sqi.Items.begin();
-    for(; it != sqi.Items.end(); ++it)
-      {
-      const Item &item = *it;
-      const DataSet &ds = item.GetNestedDataSet();
-      //const DataSet &exds = ds.GetInternal();
-      PrintDataSetOld(os << "  ", ds);
-      }
-    }
-  else if ( vl.IsUndefined() )
-    {
-    os << std::endl;
-    const SequenceOfFragments &sqf = static_cast<const SequenceOfFragments&>(value);
-    os << sqf.GetTable() << std::endl;
-    SequenceOfFragments::FragmentVector::const_iterator it = sqf.Fragments.begin();
-    for(; it != sqf.Fragments.end(); ++it)
-      {
-      const Fragment &frag = *it;
-      const Value &val = frag.GetValue(); (void)val;
-      //PrintValue(lvr, vm, val );
-      os << "  " << frag << std::endl;
-      }
-    }
-}
-
-  template <typename T>
+template <typename T>
 inline char *bswap(char *out, const char *in, size_t length)
 {
   assert( !(length % sizeof(T)) );
@@ -1084,172 +943,6 @@ void Printer::PrintDataSet(const DataSet &ds, std::ostream &out, std::string con
     }
 }
 
-//-----------------------------------------------------------------------------
-void Printer::PrintDataSetOld(std::ostream &os, const DataSet &ds)
-{
-  const Global& g = GlobalInstance;
-  const Dicts &dicts = g.GetDicts();
-  const Dict &d = dicts.GetPublicDict(); (void)d;
-
-  static const GroupDict gd; // FIXME
-//  try
-    {
-    DataSet::ConstIterator it = ds.Begin();
-    for( ; it != ds.End(); ++it )
-      {
-      const DataElement &de = *it;
-      //const DictEntry &entry = d.GetDictEntry(de.GetTag());
-      std::string owner;
-      const char *strowner = 0;
-      if( de.GetTag().IsPrivate() /*&& de.GetTag().GetElement()*/ )
-        {
-        Tag t = de.GetTag().GetPrivateCreator();
-        const ByteValue * bv = de.GetByteValue();
-        if( t.GetElement() )
-          {
-          const DataElement & de = ds.GetDataElement( t );
-          bv = de.GetByteValue();
-          }
-        else
-          {
-          //assert( vr == VR::LO );
-          //assert( vm == VM::VM1 );
-          }
-        assert( bv );
-        owner = std::string(bv->GetPointer(),bv->GetLength());
-        assert(  owner.size() );
-        if( owner[owner.size()-1] == ' ' )
-          {
-          owner.erase(owner.size()-1,1);
-          }
-        assert( owner[owner.size()-1] != ' ' );
-        strowner = owner.c_str();
-        }
-      const DictEntry &entry = dicts.GetDictEntry(de.GetTag(),strowner);
-      // Use VR from dictionary
-      VR vr = entry.GetVR();
-      VM vm = entry.GetVM();
-      // TODO: FIXME FIXME FIXME
-      const Tag& t = de.GetTag();
-      //std::cerr << t << std::endl;
-      const VR::VRType vr_read = de.GetVR();
-      if( t == Tag(0x7fe0,0x0010) )
-        {
-        assert( vr & VR::OB_OW );
-        //vr = VR::OW;
-        //vm = VM::VM1_n;
-        }
-      if ( de.GetTag().GetElement() == 0x0 )
-        {
-        assert( vm == VM::VM0 || vm == VM::VM1 ); // not found
-        vm = VM::VM1; // this is a group length (VR=UL,VM=1)
-        assert( vr == VR::INVALID || vr == VR::UL ); // not found
-        vr = VR::UL;  // this is a group length (VR=UL,VM=1)
-        }
-      else if( de.GetTag().IsPrivate() )
-        {
-        //assert( !de.GetTag().GetElement() || vr == VR::INVALID );
-        //assert( !de.GetTag().GetElement() || vm == VM::VM0 );
-        if ( vr == VR::INVALID )
-          {
-          vr = vr_read; // we have no choice for now but trust it
-          assert( vm == VM::VM0 );
-          if( vr & VR::OB_OW )
-            {
-            vm = VM::VM1;
-            }
-          else
-            {
-            vm = VM::VM1_n; // FIXME: Is this always correct ?
-            }
-          }
-        }
-      assert( vm != VM::VM0 );
-      //assert( vr != VR::INVALID );
-      /*if( vr == VR::INVALID )
-        {
-        const VM vm = entry.GetVM();
-        const Value& val = de.GetValue();
-        os << de.GetTag();
-        }
-      else */
-      if( VR::IsASCII(vr_read) || VR::IsBinary(vr_read) )
-        {
-  //  _os << de << std::endl;
-        PrintElement(os, de, entry);
-        }
-      else // INVALID case
-        {
-        const VM& vm = entry.GetVM(); (void)vm;
-        const Value& val = de.GetValue(); (void)val;
-        os << de.GetTag();
-        //if( pstyle == Printer::CONDENSED_STYLE )
-        //  {
-        //  os << " " << vr_read;
-        //  }
-          {
-          //os << " VR=" << VR::GetVRString(vr_read);
-          os << " " << VR::GetVRString(vr_read);
-          os << "(" << vr << ")";
-          }
-        if( !vr.Compatible( vr_read ) )
-          {
-          gdcmErrorMacro( "Wrong VR should be " << vr );
-          // PHILIPS_Gyroscan-12-Jpeg_Extended_Process_2_4.dcm
-          // 0008,0040 VR=SS VR(?)=US
-          // After posting to dicom newsgroup there were reasons for doing SS
-          // but in this case user should really do US...
-          }
-        //if( pstyle == Printer::CONDENSED_STYLE )
-        //  {
-        //  os << /*"\t " << std::dec << de.GetVL() << */
-        //    " ";
-        //  }
-          {
-          //_os << "\tVL=" << std::dec << de.GetVL() << "\tValueField=[";
-          os << " " << std::dec << de.GetVL() << " ";
-          }
-
-        // Use super class of the template stuff
-        //Attribute af;
-        //af.SetVR(vr_read);
-        //af.SetVM(vm);
-        //af.SetLength( val.GetLength() );
-        //std::istringstream iss;
-        //iss.str( std::string( val.GetPointer(), val.GetLength() ) );
-        //af.Read( iss );
-        //af.Print( _os );
-        //if( pstyle == Printer::CONDENSED_STYLE )
-        //  {
-        //  os << "]";
-        //  }
-        }
-      if( de.GetTag().GetElement() == 0x0 )
-        {
-        os << " (" << gd.GetName(de.GetTag().GetGroup() )
-          << ") " << entry.GetName() << std::endl;
-        }
-      else
-        {
-        const char *name = entry.GetName();
-        if( name && *name )
-          {
-          os << " " << name << std::endl;
-          }
-        else
-          {
-          //assert( strowner );
-          os << " FIXME: " << owner << std::endl;
-          }
-        }
-      }
-    }
-  //catch(std::exception &e)
-  //  {
-  //  std::cerr << "Exception:" << typeid(e).name() << std::endl;
-  //  }
-}
-
 //-----------------------------------------------------------------------------
 void DumpDataSet(const DataSet &ds, std::ostream &os )
 {
